Module Name:    src
Committed By:   msaitoh
Date:           Thu Jun 27 09:56:39 UTC 2019

Modified Files:
        src/sys/dev/pci/ixgbe: ixv.c

Log Message:
Don't call set_vfta() if any VLAN is attached.
XXX pullup-8.


To generate a diff of this commit:
cvs rdiff -u -r1.115 -r1.116 src/sys/dev/pci/ixgbe/ixv.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/pci/ixgbe/ixv.c
diff -u src/sys/dev/pci/ixgbe/ixv.c:1.115 src/sys/dev/pci/ixgbe/ixv.c:1.116
--- src/sys/dev/pci/ixgbe/ixv.c:1.115	Wed May 29 10:07:30 2019
+++ src/sys/dev/pci/ixgbe/ixv.c	Thu Jun 27 09:56:39 2019
@@ -1,4 +1,4 @@
-/*$NetBSD: ixv.c,v 1.115 2019/05/29 10:07:30 msaitoh Exp $*/
+/*$NetBSD: ixv.c,v 1.116 2019/06/27 09:56:39 msaitoh Exp $*/
 
 /******************************************************************************
 
@@ -2000,11 +2000,11 @@ ixv_setup_vlan_support(struct adapter *a
 		rxr->vtag_strip = hwtagging ? TRUE : FALSE;
 	}
 
 #if 1
 	/* XXX dirty hack. Enable all VIDs */
 	for (int i = 0; i < IXGBE_VFTA_SIZE; i++)
-	  adapter->shadow_vfta[i] = 0xffffffff;
-#endif
+		adapter->shadow_vfta[i]
+		    = VLAN_ATTACHED(&adapter->osdep.ec) ? 0xffffffff : 0;
+
 	/*
 	 * A soft reset zero's out the VFTA, so
 	 * we need to repopulate it now.
@@ -2000,11 +2000,11 @@ ixv_setup_vlan_support(struct adapter *a
 	}
 
-#if 1
-	/* XXX dirty hack. Enable all VIDs */
+	/* XXX dirty hack. Enable all VIDs if any VLAN is attached */
 	for (int i = 0; i < IXGBE_VFTA_SIZE; i++)

Reply via email to